Austrian NC 2002 - Last Chance Qualifier Vienna, Austria November 30th 2002 115 players Stéphane Lavrut Description: Here is THE wargoule deck Crypt (12 cards, min=11, max=22, avg=4.08) ------------------------------------------ 3x Lolita Houston 4 VIC aus Tzimisce:2 2x Terrence 4 ani aus vic Tzimisce:2 2x Horatio 2 vic Tzimisce:2 1x Caliban 6 ANI AUS VIC Tzimisce:2 1x Corine Marcón 6 AUS VIC ani Tzimisce:2 1x Devin Bisley 5 ANI AUS vic Tzimisce:2 1x Rose, The 5 PRE VIC aus Tzimisce:3 1x Wendy Wade 3 ani aus Tzimisce:2 Library (61 cards) Master (17) 4x Blood Doll 2x Direct Intervention 5x Jake Washington 2x Library Hunting Ground 4x Memories of Mortality Ally (13) 2x Vagabond Mystic 11x War Ghoul Retainer (9) 5x Ghoul Escort 4x Revenant Action Modifier (6) 6x Changeling Action Modifier/Combat (5) 5x Plasmic Form Reaction (2) 2x Delaying Tactics Combat (9) 2x Breath of the Dragon 7x Trap